@@ -1,15 +1,24 @@
 ;;; boxquote.el --- Quote text with a semi-box.
-;; Copyright 1999-2017 by Dave Pearson <davep@davep.org>
+;; Copyright 1999-2022 by Dave Pearson <davep@davep.org>
 
 ;; Author: Dave Pearson <davep@davep.org>
-;; Version: 2.1
+;; Version: 2.3
 ;; Keywords: quoting
 ;; URL: https://github.com/davep/boxquote.el
 ;; Package-Requires: ((cl-lib "0.5"))
 
-;; boxquote.el is free software distributed under the terms of the GNU
-;; General Public Licence, version 2 or (at your option) any later version.
-;; For details see the file COPYING.
+;; This program is free software: you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation, either version 3 of the License, or (at your
+;; option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
+;; Public License for more details.
+;;
+;; You should have received a copy of the GNU General Public License along
+;; with this program. If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -37,7 +46,7 @@
 ;; hassled him for his code but it was far more fun to write it myself.
 ;;
 ;; Mark Milhollan for providing a patch that helped me get the help quoting
-;; functions working with XEmacs. (which, for other reasons, I've neded to
+;; functions working with XEmacs. (which, for other reasons, I've needed to
 ;; remove as of v2.0 -- hopefully I can get things working on XEmacs again).
 ;;
 ;; Oliver Much for suggesting the idea of having a `boxquote-kill-ring-save'
@@ -218,7 +227,7 @@ boxquote is found."
   "Return a regular expression to match the title."
   (with-temp-buffer
     (insert (regexp-quote boxquote-title-format))
-    (setf (point) (point-min))
+    (goto-char (point-min))
     (when (search-forward "%s" nil t)
       (replace-match ".*" nil t))
     (buffer-string)))
@@ -229,15 +238,15 @@ boxquote is found."
       (with-temp-buffer
         (let ((look-for "%s"))
           (insert boxquote-title-format)
-          (setf (point) (point-min))
+          (goto-char (point-min))
           (search-forward look-for)
           (list (- (point) (length look-for) 1) (- (point-max) (point)))))
     (save-excursion
       (save-restriction
         (boxquote-narrow-to-boxquote)
-        (setf (point) (+ (point-min)
-                         (length (concat boxquote-top-corner
-                                         boxquote-top-and-tail))))
+        (goto-char (+ (point-min)
+                      (length (concat boxquote-top-corner
+                                      boxquote-top-and-tail))))
         (if (looking-at (boxquote-title-format-as-regexp))
             (buffer-substring-no-properties (+ (point) prefix-len)
                                             (- (line-end-position) suffix-len))
@@ -253,9 +262,9 @@ be formatted using `boxquote-title-format'."
   (save-excursion
     (save-restriction
       (boxquote-narrow-to-boxquote)
-      (setf (point) (+ (point-min)
-                       (length (concat boxquote-top-corner
-                                       boxquote-top-and-tail))))
+      (goto-char (+ (point-min)
+                    (length (concat boxquote-top-corner
+                                    boxquote-top-and-tail))))
       (unless (eolp)
         (kill-line))
       (unless (zerop (length title))
@@ -268,7 +277,7 @@ be formatted using `boxquote-title-format'."
   (save-excursion
     (save-restriction
       (cl-flet ((bol-at-p (n)
-                  (setf (point) n)
+                  (goto-char n)
                   (bolp))
                 (insert-corner (corner pre-break)
                   (insert (concat (if pre-break "\n" "")
@@ -277,14 +286,14 @@ be formatted using `boxquote-title-format'."
               (break-end   (not (bol-at-p end))))
           (narrow-to-region start end)
           (run-hooks 'boxquote-region-hook)
-          (setf (point) (point-min))
+          (goto-char (point-min))
           (insert-corner boxquote-top-corner break-start)
           (let ((start-point (line-beginning-position)))
-            (setf (point) (point-max))
+            (goto-char (point-max))
             (insert-corner boxquote-bottom-corner break-end)
             (string-rectangle start-point
                               (progn
-                                (setf (point) (point-max))
+                                (goto-char (point-max))
                                 (forward-line -2)
                                 (line-beginning-position))
                               boxquote-side)))))))
@@ -348,14 +357,15 @@ whatever `boxquote-kill-ring-save-title' returned at the time."
   (save-excursion
     (insert (with-temp-buffer
               (yank)
-              (setf (point) (point-min))
+              (goto-char (point-min))
               (let ((title
                      (let ((yanked (condition-case nil
                                        (read (current-buffer))
                                      (error nil))))
                        (when (listp yanked)
                          (when (eq (car yanked) 'boxquote-yank-marker)
-                           (setf (buffer-string) (nth 2 yanked))
+			   (erase-buffer)
+                           (insert (nth 2 yanked))
                            (nth 1 yanked))))))
                 (run-hooks 'boxquote-yank-hook)
                 (boxquote-buffer)
@@ -421,7 +431,7 @@ VARIABLE is the variable to describe."
   "Call `describe-key' on KEY and boxquote the output into the current buffer.
 
 If the call to this command is prefixed with \\[universal-argument] you will also be
-prompted for a buffer. The key defintion used will be taken from that buffer."
+prompted for a buffer. The key definition used will be taken from that buffer."
   (interactive "kDescribe key: ")
   (let ((from-buffer (if current-prefix-arg
                          (read-buffer "Buffer: " (current-buffer) t)
@@ -483,11 +493,11 @@ prompted for a buffer. The key defintion used will be taken from that buffer."
   (interactive)
   (let ((box (boxquote-points-with-check)))
     (narrow-to-region (save-excursion
-                        (setf (point) (car box))
+                        (goto-char (car box))
                         (forward-line 1)
                         (point))
                       (save-excursion
-                        (setf (point) (cdr box))
+                        (goto-char (cdr box))
                         (line-beginning-position)))))
 
 ;;;###autoload
@@ -515,7 +525,7 @@ prompted for a buffer. The key defintion used will be taken from that buffer."
   (save-excursion
     (save-restriction
       (narrow-to-region start end)
-      (setf (point) (point-min))
+      (goto-char (point-min))
       (if (looking-at (concat "^" (regexp-quote boxquote-top-corner)
                               (regexp-quote boxquote-top-and-tail)))
           (let ((ends (concat "^[" (regexp-quote boxquote-top-corner)
